<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>AppMgmtDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1303"/>
        <source>Manage External Applications</source>
        <translation>Spravovat vnější programy</translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="vanished">Příkaz</translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="vanished">Cesta</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="vanished">Přidat</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1315"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1317"/>
        <source>Application path and arguments</source>
        <translation>Cesta k programu a argumenty</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1323"/>
        <source>Choose</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1327"/>
        <source>Add manually</source>
        <translation>Přidat ručně</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1331"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1338"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1378"/>
        <source>Choose Application</source>
        <translation>Vybrat program</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1390"/>
        <source>New Application</source>
        <translation>Nový program</translation>
    </message>
</context>
<context>
    <name>ColorsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1008"/>
        <source>Colors</source>
        <translation>Barvy</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1014"/>
        <source>Reset</source>
        <translation>Nastavit znovu</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1019"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1027"/>
        <source>Hue</source>
        <translation>Odstín</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1028"/>
        <source>Saturation</source>
        <translation>Sytost</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1029"/>
        <source>Lightness</source>
        <translation>Světlost</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="vanished">Kanály</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="vanished">Povolit</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1038"/>
        <source>Colorize</source>
        <translation>Obarvit</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1042"/>
        <location filename="../dialogs.cpp" line="1046"/>
        <location filename="../dialogs.cpp" line="1050"/>
        <source>Negative</source>
        <translation>Negativ</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1069"/>
        <location filename="../dialogs.cpp" line="1135"/>
        <source>Red</source>
        <translation>Červená</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1074"/>
        <location filename="../dialogs.cpp" line="1143"/>
        <source>Green</source>
        <translation>Zelená</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1079"/>
        <location filename="../dialogs.cpp" line="1151"/>
        <source>Blue</source>
        <translation>Modrá</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1096"/>
        <source>Hue and Saturation</source>
        <translation>Odstín a sytost</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1102"/>
        <source>Affected Channels</source>
        <translation>Ovlivněné kanály</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1106"/>
        <source>Brightness</source>
        <translation>Jas</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1107"/>
        <source>Contrast</source>
        <translation>Kontrast</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1131"/>
        <source>Brightness and Contrast</source>
        <translation>Jas a kontrast</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1171"/>
        <source>Color Balance</source>
        <translation>Vyvážení barev</translation>
    </message>
</context>
<context>
    <name>CopyMoveToDialog</name>
    <message>
        <source>Copy or Move Images to...</source>
        <translation type="vanished">Kopírovat nebo přesunout obrázky do...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="vanished">Přidat</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1407"/>
        <source>Move to...</source>
        <translation>Přesunout do...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1410"/>
        <source>Copy to...</source>
        <translation>Kopírovat do...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1438"/>
        <source>Browse...</source>
        <translation>Procházet...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1440"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1447"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1452"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1463"/>
        <location filename="../dialogs.cpp" line="1489"/>
        <source>Destination:</source>
        <translation>Cíl:</translation>
    </message>
    <message>
        <source>Destination: </source>
        <translation type="vanished">Cíl:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Zavřít</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopírovat</translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="vanished">Přesunout</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1529"/>
        <source>Choose Folder</source>
        <translation>Vybrat složku</translation>
    </message>
</context>
<context>
    <name>CpMvDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="141"/>
        <source>Copying &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Kopíruje se &quot;%1&quot; do &quot;%2.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="142"/>
        <source>Moving &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Přesunuje se &quot;%1&quot; do &quot;%2.</translation>
    </message>
    <message>
        <source>Copying </source>
        <translation type="vanished">Kopíruje se </translation>
    </message>
    <message>
        <source>Moving </source>
        <translation type="vanished">Přesunuje se </translation>
    </message>
    <message>
        <source> to </source>
        <translation type="vanished"> do </translation>
    </message>
</context>
<context>
    <name>CropDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="688"/>
        <source>Cropping</source>
        <translation>Oříznutí</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="696"/>
        <source>Reset</source>
        <translation>Nastavit znovu</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="699"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="737"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="735"/>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="736"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="738"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
</context>
<context>
    <name>ImageTags</name>
    <message>
        <location filename="../tags.cpp" line="59"/>
        <source>Tag</source>
        <translation>Opatřit značkou</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="63"/>
        <source>Untag</source>
        <translation>Zrušit značku</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="73"/>
        <source>Clear Filters</source>
        <translation>Vyprázdnit filtry</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="66"/>
        <source>New Tag</source>
        <translation>Nová značka</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="36"/>
        <source>Image Tags</source>
        <translation>Značky obrázků</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="37"/>
        <source>Filter</source>
        <translation>Filtrovat</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="70"/>
        <source>Remove Tag</source>
        <translation>Odstranit značku</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="77"/>
        <source>Negate</source>
        <translation>Vyloučit</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <location filename="../tags.cpp" line="482"/>
        <location filename="../tags.cpp" line="491"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <source>Failed to save tags to </source>
        <translation>Nepodařilo se uložit značky do </translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="381"/>
        <source>Tagging </source>
        <translation>Značkuje se</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="384"/>
        <source>Untagging </source>
        <translation>Ruší se značky </translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="473"/>
        <source>Add a new tag</source>
        <translation>Přidat novou značku</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="474"/>
        <source>Enter new tag name</source>
        <translation>Zadat název nové značky</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="482"/>
        <source>No name entered</source>
        <translation>Nebyl zadán žádný název</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source>Tag </source>
        <translation>Značka</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source> already exists</source>
        <translation> již existuje</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="508"/>
        <source>Remove selected tags(s)?</source>
        <translation>Odstranit vybranou značku(y)?</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="509"/>
        <source>Remove tag</source>
        <translation>Odstranit značku</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="514"/>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="515"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <location filename="../imageview.cpp" line="626"/>
        <source>Clipboard</source>
        <translation>Schránka</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="780"/>
        <source>Selection size: </source>
        <translation>Velikost výběru:  </translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>No selection</source>
        <translation>Žádný výběr</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>Hold down the Ctrl key and select a region using the mouse.</source>
        <translation>Podržte klávesu Ctrl a pomocí myši vyberte oblast.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Failed to save image.</source>
        <translation>Nepodařilo se uložit obrázek.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="988"/>
        <source>Failed to save Exif metadata.</source>
        <translation>Nepodařilo se uložit popisná data EXIF.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="993"/>
        <location filename="../imageview.cpp" line="1034"/>
        <source>Image saved.</source>
        <translation>Obrázek uložen.</translation>
    </message>
    <message>
        <source>Hold down the Ctrl key and select a region using the mouse</source>
        <translation type="vanished">Podržte klávesu Ctrl a pomocí myši vyberte oblast</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="958"/>
        <source>Saving...</source>
        <translation>Ukládá se...</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="988"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Failed to save image</source>
        <translation type="vanished">Nepodařilo se uložit obrázek</translation>
    </message>
    <message>
        <source>Failed to save Exif metadata</source>
        <translation type="vanished">Nepodařilo se uložit popisná data EXIF</translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation type="vanished">Obrázek uložen</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1005"/>
        <source>Save image as</source>
        <translation>Uložit obrázek jako</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1007"/>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="vanished">Obrázkové soubory</translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="40"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
</context>
<context>
    <name>KeyGrabLineEdit</name>
    <message>
        <source>Set shortcut</source>
        <translation type="vanished">Nastavit klávesovou zkratku</translation>
    </message>
    <message>
        <source> is reserved for shortcuts to external applications</source>
        <translation type="vanished"> je vyhrazeno pro klávesové zkratky vnějších programů</translation>
    </message>
    <message>
        <source> is already assigned to &quot;</source>
        <translation type="vanished"> je již přiřazeno činnosti &quot;</translation>
    </message>
    <message>
        <source>&quot; action</source>
        <translation type="vanished">&quot;</translation>
    </message>
</context>
<context>
    <name>Phototonic</name>
    <message>
        <location filename="../mainwindow.cpp" line="2232"/>
        <source>Docks and Toolbars</source>
        <translation>Panely a nástrojové pruhy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Image Info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Zoom</source>
        <translation>Zvětšení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Transform</source>
        <translation>Proměna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>Mirroring</source>
        <translation>Zrcadlení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Top</source>
        <translation>Ve složce nahoru</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Bottom</source>
        <translation>Ve složce dolů</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Close Image</source>
        <translation>Zavřít obrázek</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Full Screen</source>
        <translation>Na celou obrazovku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Preferences</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Enlarge Thumbnails</source>
        <translation>Zvětšit náhledy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Shrink Thumbnails</source>
        <translation>Zmenšit náhledy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Copy or Move to...</source>
        <translation type="vanished">Kopírovat nebo přesunout do...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Save As</source>
        <translation>Uložit jako</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation type="vanished">Kopírovat obrázek</translation>
    </message>
    <message>
        <source>Paste Image</source>
        <translation type="vanished">Vložit obrázek</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="3151"/>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>Select All</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Reverse</source>
        <translation>Obráceně</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Show Hidden Files</source>
        <translation>Ukázat skryté soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Show Labels</source>
        <translation>Ukázat štítky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Small Icons</source>
        <translation>Malé ikony</translation>
    </message>
    <message>
        <source>Hide Docks Title Bar</source>
        <translation type="vanished">Skrýt název panelu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Classic Thumbs</source>
        <translation>Klasické náhledy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Compact</source>
        <translation>Zabírající málo místa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Squarish</source>
        <translation>Přibližně čtvercové</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Reload</source>
        <translation>Nahrát znovu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Include Sub-folders</source>
        <translation>Zahrnout podsložky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Paste Here</source>
        <translation>Vložit zde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="465"/>
        <source>New Folder</source>
        <translation>Nová složka</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="vanished">Spravovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Forward</source>
        <translation>Vpřed</translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="vanished">Nahoru</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Home</source>
        <translation>Začáteční stránka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <source>Slide Show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <source>First</source>
        <translation>První</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Last</source>
        <translation>Poslední</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Random</source>
        <translation>Náhodný</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Show Clipboard</source>
        <translation type="vanished">Ukázat schránku</translation>
    </message>
    <message>
        <source>Open With</source>
        <translation type="vanished">Otevřít pomocí</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Manage External Applications</source>
        <translation>Spravovat vnější programy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Zoom Out</source>
        <translation>Oddálit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Zoom In</source>
        <translation>Přiblížit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Reset Zoom</source>
        <translation>Nastavit zvětšení znovu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>Original Size</source>
        <translation>Původní velikost</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Keep Zoom</source>
        <translation>Zachovat zvětšení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Rotate 90 degree CCW</source>
        <translation>Otočit vlevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Rotate 90 degree CW</source>
        <translation>Otočit vpravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Flip Horizontally</source>
        <translation>Převrátit vodorovně</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>Flip Vertically</source>
        <translation>Převrátit svisle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Cropping</source>
        <translation>Oříznutí</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>Scale Image</source>
        <translation>Změnit velikost obrázku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Rotate 1 degree CCW</source>
        <translation>Otočit o 1 stupeň vlevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Rotate 1 degree CW</source>
        <translation>Otočit o 1 stupeň vpravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Colors</source>
        <translation>Barvy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Disable</source>
        <translation>Zakázat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <source>Dual</source>
        <translation>Dvojice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Triple</source>
        <translation>Trojice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Dual Vertical</source>
        <translation>Dvojice svisle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Quad</source>
        <translation>Čtveřice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Tags</source>
        <translation>Značky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Minimum zoom</source>
        <translation>Nejmenší zvětšení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Maximum zoom</source>
        <translation>Největší zvětšení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1459"/>
        <location filename="../mainwindow.cpp" line="1468"/>
        <location filename="../mainwindow.cpp" line="1525"/>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>Rotation %1°</source>
        <translation>Otočení %1°</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2703"/>
        <source>Failed to open file &quot;%1&quot;, file not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to open file &quot;%1&quot;: file not found.</source>
        <translation type="vanished">Nepodařilo se otevřít obrázek &quot;%1&quot;: soubor nebyl nalezen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2983"/>
        <source>Can not move or copy images to this folder.</source>
        <translation>Nelze přesunout nebo kopírovat obrázky do této složky.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2989"/>
        <source>Destination folder is same as source.</source>
        <translation>Cílová složka je stejná jako zdroj.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2997"/>
        <source>Move &quot;%1&quot; to &quot;%2&quot;?</source>
        <translation>Přesunout &quot;%1&quot; do &quot;%2?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3006"/>
        <source>Failed to move folder.</source>
        <translation>Nepodařilo se přesunout složku.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3108"/>
        <source>Failed to open folder:</source>
        <translation>Nepodařilo se otevřít složku:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3140"/>
        <source>Duplicate images in %1</source>
        <translation>Zdvojit obrázky v %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <source>Invalid name entered.</source>
        <translation>Zadán neplatný název.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3175"/>
        <source>Failed to rename folder.</source>
        <translation>Nepodařilo se přejmenovat složku.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3222"/>
        <source>Enter a new name for &quot;%1&quot;:</source>
        <translation>Zadat nový název pro &quot;%1&quot;:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3235"/>
        <source>No name entered.</source>
        <translation>Nebyl zadán žádný název.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3265"/>
        <source>Failed to rename image.</source>
        <translation>Nepodařilo se přejmenovat obrázek.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3281"/>
        <source>Permanently delete &quot;%1&quot; and all of its contents?</source>
        <translation>Smazat trvale &quot;%1&quot; a veškerý jeho obsah?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3304"/>
        <source>Failed to delete folder.</source>
        <translation>Nepodařilo se smazat složku.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3308"/>
        <source>Removed &quot;%1&quot;</source>
        <translation>Odstraněno &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Failed to create new folder.</source>
        <translation>Nepodařilo se vytvořit novou složku.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3354"/>
        <source>Created &quot;%1&quot;</source>
        <translation>Vytvořeno &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Cannot perform action with temporary image.</source>
        <translation>Činnost nelze s dočasným souborem provést.</translation>
    </message>
    <message>
        <source>Keep Transformations</source>
        <translation type="vanished">Zachovat proměny</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Move Left</source>
        <translation>Posunout vlevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <source>Move Right</source>
        <translation>Posunout vpravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Move Up</source>
        <translation>Posunout nahoru</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Move Down</source>
        <translation>Posunout dolů</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Invert Selection</source>
        <translation>Obrátit výběr</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>&amp;Edit</source>
        <translation>Úp&amp;ravy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>&amp;Go</source>
        <translation>&amp;Pohyb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>&amp;View</source>
        <translation>Po&amp;hled</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Sort By</source>
        <translation>Řadit dle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>&amp;Help</source>
        <translation>Nápo&amp;věda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="771"/>
        <source>Edit</source>
        <translation>Úpravy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Navigation</source>
        <translation>Pohyb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <location filename="../mainwindow.cpp" line="253"/>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="808"/>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>Initializing...</source>
        <translation>Spouští se...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>File System</source>
        <translation>Souborový systém</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1044"/>
        <source>&lt;p&gt;Image viewer and organizer&lt;/p&gt;</source>
        <translation>&lt;p&gt;Prohlížeč a správce obrázků&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <source>Failed to start external application.</source>
        <translation>Nepodařilo se spustit vnější program.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1128"/>
        <source>Invalid selection.</source>
        <translation>Neplatný výběr.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1330"/>
        <source>Failed to copy or move image.</source>
        <translation>Nepodařilo se kopírovat nebo přesunout obrázek.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1390"/>
        <location filename="../mainwindow.cpp" line="1408"/>
        <source>Zoom %1%</source>
        <translation>Zvětšení %1%</translation>
    </message>
    <message>
        <source>Rotation %1u00B0</source>
        <translation type="vanished">Otočení %1u00B0</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Copied</source>
        <translation>Zkopírováno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Moved</source>
        <translation>Přesunout</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1676"/>
        <location filename="../mainwindow.cpp" line="1870"/>
        <location filename="../mainwindow.cpp" line="3028"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n obrázek</numerusform>
            <numerusform>%n obrázky</numerusform>
            <numerusform>%n obrázků</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1739"/>
        <source>Permanently delete</source>
        <translation>Smazat trvale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1842"/>
        <source>Failed to delete image.</source>
        <translation>Nepodařilo se smazat obrázek.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1870"/>
        <source>Deleted</source>
        <translation>Smazáno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1902"/>
        <source>Invalid Path:</source>
        <translation>Neplatná cesta:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2216"/>
        <source>Viewer</source>
        <translation>Prohlížeč</translation>
    </message>
    <message>
        <source>&lt;p&gt;Git build v1.03.02 (</source>
        <translation type="vanished">&lt;p&gt;Sestavení Git v1.03.02 (</translation>
    </message>
    <message>
        <source>Built with Qt </source>
        <translation type="vanished">Sestaveno s Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1046"/>
        <source>Home page</source>
        <translation>Domovská stránka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1047"/>
        <source>Bug reports</source>
        <translation>Hlášení chyb</translation>
    </message>
    <message>
        <source>Contributors:&lt;br&gt;</source>
        <translation type="vanished">Přispěvatelé:&lt;br&gt;</translation>
    </message>
    <message>
        <source>Contributors / Translations:&lt;br&gt;</source>
        <translation type="vanished">Přispěvatelé/Překladatelé:&lt;br&gt;</translation>
    </message>
    <message>
        <source>Translators:&lt;br&gt;</source>
        <translation type="vanished">Překladatelé:&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3208"/>
        <source>Invalid selection</source>
        <translation>Neplatný výběr</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <location filename="../mainwindow.cpp" line="1330"/>
        <location filename="../mainwindow.cpp" line="1638"/>
        <location filename="../mainwindow.cpp" line="1651"/>
        <location filename="../mainwindow.cpp" line="1761"/>
        <location filename="../mainwindow.cpp" line="1842"/>
        <location filename="../mainwindow.cpp" line="1902"/>
        <location filename="../mainwindow.cpp" line="2703"/>
        <location filename="../mainwindow.cpp" line="2983"/>
        <location filename="../mainwindow.cpp" line="2989"/>
        <location filename="../mainwindow.cpp" line="3006"/>
        <location filename="../mainwindow.cpp" line="3108"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3175"/>
        <location filename="../mainwindow.cpp" line="3235"/>
        <location filename="../mainwindow.cpp" line="3265"/>
        <location filename="../mainwindow.cpp" line="3304"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Failed to start external application</source>
        <translation type="vanished">Nepodařilo se spustit vnější program</translation>
    </message>
    <message>
        <source>Failed to copy or move image</source>
        <translation type="vanished">Nepodařilo se kopírovat nebo přesunout obrázek</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1638"/>
        <source>Can not copy or move to </source>
        <translation>Nelze kopírovat nebo přesunout obrázky</translation>
    </message>
    <message>
        <source>Can not cut and paste in the same folder</source>
        <translation type="vanished">Nelze vyjmout a vložit do téže složky</translation>
    </message>
    <message>
        <source>Copied </source>
        <translation type="vanished">Zkopírováno </translation>
    </message>
    <message>
        <source>Moved </source>
        <translation type="vanished">Přesunuto </translation>
    </message>
    <message>
        <source> images</source>
        <translation type="vanished"> obrázků</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1740"/>
        <source>Delete image</source>
        <translation>Smazat obrázek</translation>
    </message>
    <message>
        <source>Permanently delete </source>
        <translation type="vanished">Smazat trvale </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1761"/>
        <source>Failed to delete image</source>
        <translation>Nepodařilo se smazat obrázek</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1507"/>
        <location filename="../mainwindow.cpp" line="1798"/>
        <source>No selection</source>
        <translation>Žádný výběr</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1807"/>
        <source>Delete images</source>
        <translation>Smazat obrázky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <source>Permanently delete selected images?</source>
        <translation>Trvale smazat vybrané obrázky?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Copy to...</source>
        <translation>Kopírovat do...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Move to...</source>
        <translation>Přesunout do...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Copy Image Data</source>
        <translation>Kopírovat data obrázku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Paste Image Data</source>
        <translation>Vložit data obrázku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Hide Dock Title Bars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Show Toolbar</source>
        <translation>Ukázat nástrojový pruh</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Go Up</source>
        <translation>Nadřízený adresář</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Load Clipboard</source>
        <translation>Nahrát schránku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Open With...</source>
        <translation>Otevřít s...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Add Bookmark</source>
        <translation>Přidat záložku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Remove Bookmark</source>
        <translation>Odstranit záložku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Crop to Selection</source>
        <translation>Oříznout výběr</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Find Duplicate Images</source>
        <translation>Najít zdvojené obrázky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Lock Transformations</source>
        <translation>Uzamknout proměny</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Filter by Name</source>
        <translation>Filtrovat podle názvu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Set Path</source>
        <translation>Nastavit cestu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>&amp;Tools</source>
        <translation>&amp;Nástroje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>Image</source>
        <translation>Obrázek</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <source>Contributors / Code:</source>
        <translation type="vanished">Přispěvatelé (kód):</translation>
    </message>
    <message>
        <source>Contributors / Translations:</source>
        <translation type="vanished">Překladatelé:</translation>
    </message>
    <message>
        <source>Zoom </source>
        <translation type="vanished">Zvětšení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1416"/>
        <source>Zoom Reset</source>
        <translation>Nastavit zvětšení znovu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>Zoom Locked</source>
        <translation>Zvětšení zamknuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1433"/>
        <source>Zoom Unlocked</source>
        <translation>Zvětšení odemknuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1442"/>
        <source>Transformations Locked</source>
        <translation>Proměny zamknuty</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1447"/>
        <source>Transformations Unlocked</source>
        <translation>Proměny odemknuty</translation>
    </message>
    <message>
        <source>Rotation </source>
        <translation type="vanished">Otočení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Flipped Vertically</source>
        <translation>Převráceno svisle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Unflipped Vertically</source>
        <translation>Svislé převrácení zrušeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Flipped Horizontally</source>
        <translation>Převráceno vodorovně</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Unflipped Horizontally</source>
        <translation>Vodorovné převrácení zrušeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1578"/>
        <source>Mirroring Disabled</source>
        <translation>Zrcadlení zakázáno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1585"/>
        <source>Mirroring: Dual</source>
        <translation>Zrcadlení: Dvojice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Mirroring: Triple</source>
        <translation>Zrcadlení: Trojice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1599"/>
        <source>Mirroring: Dual Vertical</source>
        <translation>Zrcadlení: Dvojice svisle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1606"/>
        <source>Mirroring: Quad</source>
        <translation>Zrcadlení: Čtveřice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1651"/>
        <source>Can not copy or move to the same folder</source>
        <translation>Nelze přesunout nebo kopírovat do stejné složky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1744"/>
        <location filename="../mainwindow.cpp" line="1811"/>
        <location filename="../mainwindow.cpp" line="3289"/>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1745"/>
        <location filename="../mainwindow.cpp" line="1812"/>
        <location filename="../mainwindow.cpp" line="3290"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1758"/>
        <source>Deleted </source>
        <translation>Smazáno </translation>
    </message>
    <message>
        <source>Invalid Path: </source>
        <translation type="vanished">Neplatná cesta: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2554"/>
        <source>No images</source>
        <translation>Žádné obrázky</translation>
    </message>
    <message>
        <source>Failed to open file </source>
        <translation type="vanished">Nepodařilo se otevřít obrázek</translation>
    </message>
    <message>
        <source>, file not found</source>
        <translation type="vanished">, soubor nebyl nalezen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2718"/>
        <source>Slide show stopped</source>
        <translation>Promítání zastaveno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2745"/>
        <source>Stop Slide Show</source>
        <translation>Zastavit promítání</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2746"/>
        <source>Slide show started</source>
        <translation>Promítání spuštěno</translation>
    </message>
    <message>
        <source>Can not move or copy images to this folder</source>
        <translation type="vanished">Nelze přesunout nebo kopírovat obrázky do této složky</translation>
    </message>
    <message>
        <source>Destination folder is same as source</source>
        <translation type="vanished">Cílová složka je stejná jako zdroj</translation>
    </message>
    <message>
        <source>Move </source>
        <translation type="vanished">Přesunout</translation>
    </message>
    <message>
        <source> to </source>
        <translation type="vanished"> do </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2998"/>
        <source>Move folder</source>
        <translation>Přesunout složku</translation>
    </message>
    <message>
        <source>Failed to move folder</source>
        <translation type="vanished">Nepodařilo se přesunout složku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3008"/>
        <source>Folder moved</source>
        <translation>Složka přesunuta</translation>
    </message>
    <message>
        <source>Failed to open folder: </source>
        <translation type="vanished">Nepodařilo se otevřít složku: </translation>
    </message>
    <message>
        <source>Rename </source>
        <translation type="vanished">Přejmenovat </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3153"/>
        <source>New name:</source>
        <translation>Nový název:</translation>
    </message>
    <message>
        <source>Invalid name entered</source>
        <translation type="vanished">Zadán neplatný název</translation>
    </message>
    <message>
        <source>Failed to rename folder</source>
        <translation type="vanished">Nepodařilo se přejmenovat složku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3220"/>
        <source>Rename Image</source>
        <translation>Přejmenovat obrázek</translation>
    </message>
    <message>
        <source>Enter a new name for </source>
        <translation type="vanished">Zadat nový název pro </translation>
    </message>
    <message>
        <source>No name entered</source>
        <translation type="vanished">Nebyl zadán žádný název</translation>
    </message>
    <message>
        <source>Failed to rename image</source>
        <translation type="vanished">Nepodařilo se přejmenovat obrázek</translation>
    </message>
    <message>
        <source> and all of its contents?</source>
        <translation type="vanished"> a veškerý jeho obsah?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3285"/>
        <source>Delete folder</source>
        <translation>Smazat složku</translation>
    </message>
    <message>
        <source>Failed to delete folder</source>
        <translation type="vanished">Nepodařilo se smazat složku</translation>
    </message>
    <message>
        <source>Removed </source>
        <translation type="vanished">Odstraněno </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3326"/>
        <source>New Sub folder</source>
        <translation>Nová podsložka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3327"/>
        <source>New folder name:</source>
        <translation>Nová název složky:</translation>
    </message>
    <message>
        <source>Failed to create new folder</source>
        <translation type="vanished">Nepodařilo se vytvořit novou složku</translation>
    </message>
    <message>
        <source>Created </source>
        <translation type="vanished">Vytvořeno </translation>
    </message>
    <message>
        <source>Executing file manager...</source>
        <translation type="vanished">Spustit správce souborů...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>Cannot perform action with temporary image</source>
        <translation type="vanished">Činnost nelze s dočasným souborem provést</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1555"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Usage: phototonic [FILE or DIRECTORY]...</source>
        <translation type="vanished">Použití: phototonic [SOUBOR nebo ADRESÁŘ]...</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="813"/>
        <source>Scale Image</source>
        <translation>Změnit velikost obrázku</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="825"/>
        <source>Scale</source>
        <translation>Změnit velikost</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="829"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="845"/>
        <source>Original size:</source>
        <translation>Původní velikost:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="848"/>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="849"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="850"/>
        <source>Units:</source>
        <translation>Jednotky:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="852"/>
        <source>New size:</source>
        <translation>Nová velikost:</translation>
    </message>
    <message>
        <source>Original size: </source>
        <translation type="vanished">Původní velikost: </translation>
    </message>
    <message>
        <source>Width: </source>
        <translation type="vanished">Šířka: </translation>
    </message>
    <message>
        <source>Height: </source>
        <translation type="vanished">Výška: </translation>
    </message>
    <message>
        <source>Units: </source>
        <translation type="vanished">Jednotky: </translation>
    </message>
    <message>
        <source>New size: </source>
        <translation type="vanished">Nová velikost: </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="855"/>
        <source>Pixels</source>
        <translation>Pixelů</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="857"/>
        <source>Percent</source>
        <translation>Procento</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="862"/>
        <source>Lock aspect ratio</source>
        <translation>Zamknout poměr stran</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="270"/>
        <source>Preferences</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="277"/>
        <location filename="../dialogs.cpp" line="294"/>
        <source>By width or height</source>
        <translation>Podle šířky nebo výšky</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="331"/>
        <source>Default quality when saving images:</source>
        <translation>Výchozí jakost obrazu při ukládání obrázků:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="383"/>
        <source>Label color:</source>
        <translation>Barva štítku:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="545"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="550"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Background color: </source>
        <translation type="vanished">Barva pozadí:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="345"/>
        <source>Rotate image according to Exif orientation</source>
        <translation>Otočit obrázek podle údaje o natočení v EXIF</translation>
    </message>
    <message>
        <source>	Label color: </source>
        <translation type="vanished">	Barva štítku: </translation>
    </message>
    <message>
        <source>Background image: </source>
        <translation type="vanished">Obrázek pozadí:</translation>
    </message>
    <message>
        <source>Add space between thumbnails: </source>
        <translation type="vanished">Vložit mezi náhledy odstup: </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="425"/>
        <source>Show original size of images smaller than the thumbnail size</source>
        <translation>Ukázat původní velikost obrázků menších, než je velikost náhledu</translation>
    </message>
    <message>
        <source>Number of thumbnail pages to read ahead: </source>
        <translation type="vanished">Počet stránek s náhledy k načtení dopředu:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="438"/>
        <source>Rotate thumbnails according to Exif orientation</source>
        <translation>Otočit náhledy podle údaje o natočení v EXIF</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="566"/>
        <source>Thumbnails</source>
        <translation>Náhledy</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="275"/>
        <source>Fit Large Images</source>
        <translation>Přizpůsobit velké obrázky</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="276"/>
        <location filename="../dialogs.cpp" line="293"/>
        <source>Disable</source>
        <translation>Zakázat</translation>
    </message>
    <message>
        <source>By width and height</source>
        <translation type="vanished">Podle šířky a výšky</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="278"/>
        <location filename="../dialogs.cpp" line="295"/>
        <source>By width</source>
        <translation>Podle šířky</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="279"/>
        <location filename="../dialogs.cpp" line="296"/>
        <source>By height</source>
        <translation>Podle výšky</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <location filename="../dialogs.cpp" line="297"/>
        <source>Stretch disproportionately</source>
        <translation>Roztáhnout nepoměrně</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Fit Small Images</source>
        <translation>Přizpůsobit malé obrázky</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="323"/>
        <source>Exit instead of closing, when image is loaded from command line</source>
        <translation>Ukončit místo zavření, když je obrázek nahrán z příkazového řádku</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="327"/>
        <source>Wrap image list when reaching last or first image</source>
        <translation>Zalomit seznam obrázků, když je dosaženo posledního nebo prvního obrázku</translation>
    </message>
    <message>
        <source>Default quality when saving images: </source>
        <translation type="vanished">Výchozí jakost obrazu při ukládání obrázků: </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="341"/>
        <source>Enable GIF animation</source>
        <translation>Povolit animaci GIF</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="681"/>
        <source>Open File</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="682"/>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Rotate according to Exif orientation</source>
        <translation type="vanished">Otočit podle údaje o natočení v EXIF</translation>
    </message>
    <message>
        <source>Show image file name in full screen mode</source>
        <translation type="vanished">Zobrazit název souboru obrázku v režimu celé obrazovky</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="309"/>
        <location filename="../dialogs.cpp" line="371"/>
        <source>Background color:</source>
        <translation>Barva pozadí:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="349"/>
        <source>Show image file name in viewer</source>
        <translation>Zobrazit název souboru obrázku v prohlížeči</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="395"/>
        <source>Background image:</source>
        <translation>Obrázek pozadí:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="414"/>
        <source>Add space between thumbnails:</source>
        <translation>Vložit mezi náhledy odstup:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="429"/>
        <source>Number of thumbnail pages to read ahead:</source>
        <translation>Počet stránek s náhledy, jež se mají načíst dopředu:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="452"/>
        <source>Delay between slides in seconds:</source>
        <translation>Zpoždění mezi snímky v sekundách:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="472"/>
        <source>Startup folder</source>
        <translation>Složka při spuštění programu</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="474"/>
        <source>Default, or specified by command line argument</source>
        <translation>Výchozí nebo stanovená parametrem příkazového řádku</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="475"/>
        <source>Remember last</source>
        <translation>Zapamatovat si poslední</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="476"/>
        <source>Specify:</source>
        <translation>Vybrat:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="527"/>
        <source>Delete confirmation</source>
        <translation>Potvrzení smazání</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="531"/>
        <source>Keyboard Shortcuts</source>
        <translation>Klávesové zkratky</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="562"/>
        <source>Viewer</source>
        <translation>Prohlížeč</translation>
    </message>
    <message>
        <source>Delay between slides in seconds: </source>
        <translation type="vanished">Zpoždění mezi snímky v sekundách: </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="462"/>
        <source>Show random images</source>
        <translation>Ukázat náhodně vybrané obrázky</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="570"/>
        <source>Slide Show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="523"/>
        <source>Swap mouse left-click and middle-click actions</source>
        <translation>Vyměnit klepnutí levým tlačítkem myši za klepnutí prostředním tlačítkem</translation>
    </message>
    <message>
        <source>Keyboard Shortcuts:</source>
        <translation type="vanished">Klávesové zkratky:</translation>
    </message>
    <message>
        <source>Keyboard and Mouse</source>
        <translation type="vanished">Klávesnice a myš</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="574"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="674"/>
        <source>Choose Startup Folder</source>
        <translation>Vybrat složku při spuštění programu</translation>
    </message>
</context>
<context>
    <name>ShortcutsTable</name>
    <message>
        <location filename="../dialogs.cpp" line="170"/>
        <source>Action</source>
        <translation>Činnost</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="171"/>
        <source>Shortcut</source>
        <translation>Klávesová zkratka</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>Delete shortcut</source>
        <translation>Smazat klávesovou zkratku</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="227"/>
        <location filename="../dialogs.cpp" line="239"/>
        <source>Set shortcut</source>
        <translation>Nastavit klávesovou zkratku</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="228"/>
        <source>&quot;%1&quot; is reserved for shortcuts to external applications.</source>
        <translation>&quot;%1&quot; je vyhrazeno pro klávesové zkratky vnějších programů.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="240"/>
        <source>&quot;%1&quot; is already assigned to &quot;%2&quot; action.</source>
        <translation>&quot;%1&quot; je již přiřazeno činnosti &quot;%2&quot;.</translation>
    </message>
    <message>
        <source> is reserved for shortcuts to external applications</source>
        <translation type="obsolete"> je vyhrazeno pro klávesové zkratky vnějších programů</translation>
    </message>
    <message>
        <source> is already assigned to &quot;</source>
        <translation type="obsolete"> je již přiřazeno činnosti &quot;</translation>
    </message>
    <message>
        <source>&quot; action</source>
        <translation type="obsolete">&quot;</translation>
    </message>
</context>
<context>
    <name>ThumbView</name>
    <message>
        <source> images</source>
        <translation type="vanished"> obrázků</translation>
    </message>
    <message>
        <source>Selected </source>
        <translation type="vanished">Vybráno</translation>
    </message>
    <message>
        <source> of </source>
        <translation type="vanished"> z </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="247"/>
        <source>File name</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="251"/>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="264"/>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="268"/>
        <source>Resolution</source>
        <translation>Rozlišení</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="274"/>
        <source>Megapixel</source>
        <translation>Megapixelů</translation>
    </message>
    <message>
        <source>Selected %1 of %2</source>
        <translation type="vanished">Vybráno %1 z %2</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="683"/>
        <source>Scanned %1, displaying %2 (%3 and %4)</source>
        <translation>Prohledáno %1, zobrazuje se %2 (%3 a %4)</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="686"/>
        <source>%n original(s)</source>
        <translation>
            <numerusform>%n originál</numerusform>
            <numerusform>%n originály</numerusform>
            <numerusform>%n originálů</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="687"/>
        <source>%n duplicate(s)</source>
        <translation>
            <numerusform>%n zdvojený obrázek</numerusform>
            <numerusform>%n zdvojené obrázky</numerusform>
            <numerusform>%n zdvojených obrázků</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="255"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="245"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="259"/>
        <source>Modified</source>
        <translation>Změněno</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="282"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="463"/>
        <location filename="../thumbview.cpp" line="684"/>
        <location filename="../thumbview.cpp" line="685"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n obrázek</numerusform>
            <numerusform>%n obrázky</numerusform>
            <numerusform>%n obrázků</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="297"/>
        <source>Selected %1 of%2</source>
        <translation>Vybráno %1 z%2</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="299"/>
        <source> %n image(s)</source>
        <translation>
            <numerusform> %n obrázek</numerusform>
            <numerusform> %n obrázky</numerusform>
            <numerusform> %n obrázků</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="582"/>
        <source>Searching duplicate images...</source>
        <translation>Hledají se zdvojené obrázky...</translation>
    </message>
    <message>
        <source>Scanned </source>
        <translation type="vanished">Prohledáno</translation>
    </message>
    <message numerus="yes">
        <source>%n images, displaying </source>
        <translation type="vanished">
            <numerusform>%n obrázek, zobrazuje se </numerusform>
            <numerusform>%n obrázky, zobrazují se </numerusform>
            <numerusform>%n obrázků, zobrazuje se </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n images (</source>
        <translation type="vanished">
            <numerusform>%n obrázek (</numerusform>
            <numerusform>%n obrázky (</numerusform>
            <numerusform>%n obrázků (</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n originals and </source>
        <translation type="obsolete">
            <numerusform>%n originál a </numerusform>
            <numerusform>%n originály a</numerusform>
            <numerusform>%n originálů a</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n duplicates)</source>
        <translation type="obsolete">
            <numerusform>%n zdvojený obrázek)</numerusform>
            <numerusform>%n zdvojené obrázky)</numerusform>
            <numerusform>%n zdvojených obrázků)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="465"/>
        <source>No images</source>
        <translation>Žádné obrázky</translation>
    </message>
</context>
</TS>
